unit OpenPro1;
{
  Vcl open_as_Project Expert for Delphi2 only

  Author:  Martin_Waldenburg
  Created: 3.97
  Version: 1.1
  Status:  FreeWare

  DISCLAIMER: This is provided as is, expressly without a warranty of any kind.
              You use it at your own risc.

  Install it like any other component.
}

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExptIntf, ToolIntf;

type
  Topen_as_ProjectExpert = class(TIExpert)
  private
    MenuItem: TIMenuItemIntf;
  protected
    procedure OnClick( Sender: TIMenuItemIntf); virtual;
  public
    constructor Create; virtual;
    destructor Destroy; override;
    function GetName: string; override;
    function GetAuthor: string; override;
    function GetStyle: TExpertStyle; override;
    function GetIDString: string; override;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterLibraryExpert(Topen_as_ProjectExpert.Create);
end;

{ Topen_as_ProjectExpert code }
function Topen_as_ProjectExpert.GetName: String;
begin
  Result := 'open_as_ProjectExpert'
end;

function Topen_as_ProjectExpert.GetAuthor: String;
begin
  Result := 'Martin_Waldenburg'; { author }
end;

function Topen_as_ProjectExpert.GetStyle: TExpertStyle;
begin
  Result := esAddIn;
end;

function Topen_as_ProjectExpert.GetIDString: String;
begin
  Result := 'private.open_as_ProjectExpert';
end;

constructor Topen_as_ProjectExpert.Create;
var
  Main: TIMainMenuIntf;
  ReferenceMenuItem: TIMenuItemIntf;
  Menu: TIMenuItemIntf;
begin
  inherited Create;
  MenuItem := nil;
  if ToolServices <> nil then begin { I'm an expert! }
    Main := ToolServices.GetMainMenu;
    if Main <> nil then begin { we've got the main menu! }
      try 
        { add the menu of your choice }
        ReferenceMenuItem := Main.FindMenuItem('FileOpenItem');
        if ReferenceMenuItem <> nil then
        try
          Menu := ReferenceMenuItem.GetParent;
          if Menu <> nil then
          try
            MenuItem := Menu.InsertItem(ReferenceMenuItem.GetIndex+1,
                              'Open as Project',
                              'open_as_ProjectExpertItem','',
                              0,0,0,
                              [mfEnabled, mfVisible], OnClick);
          finally
            Menu.DestroyMenuItem;
          end;
        finally
          ReferenceMenuItem.DestroyMenuItem;
        end;
      finally
        Main.Free;
      end;
    end;
  end;
end;

destructor Topen_as_ProjectExpert.Destroy;
begin
  if MenuItem <> nil then
    MenuItem.DestroyMenuItem;
  inherited Destroy;
end;{Destroy}

procedure Topen_as_ProjectExpert.OnClick( Sender: TIMenuItemIntf);
begin
  with TOpenDialog.Create(nil) do
    try
      Filter:= '*.pas files|*.pas|*.dpr files|*.dpr|all files|*.*';
      Title:= 'Open as Project';
      if Execute then ToolServices.OpenProject(FileName);
    finally
      Free;
    end;
end;

end.